#!/bin/sh -e


LEMS_HOME=/opt/le-mans

mkdir -p $LEMS_HOME/gc-log $LEMS_HOME/log $LEMS_HOME/hprof $LEMS_HOME/sandbox || true

rm -fr $LEMS_HOME/log/host.*.log.lck

JAVA_OPTS="${JAVA_OPTS:-} \
-showversion \
-XshowSettings \
-XX:+PrintCommandLineFlags \
-XX:+ExitOnOutOfMemoryError \
-Xlog:gc*=info:file=$LEMS_HOME/gc-log/gc.log:time,uptime,level,tags:filecount=5,filesize=10m"

IPV4_EXTERNAL=$(ip route get 8.8.8.8 | awk 'NR==1 {print $NF}')

if [ -z $BINDING_ADDRESS ]
then
  BINDING_ADDRESS="0.0.0.0"
fi
echo "Setting bind address to: $BINDING_ADDRESS"

if [ -z $BINDING_PORT ]
then
  BINDING_PORT=8000
fi
echo "Setting port to: $BINDING_PORT"


echo "Setting public URI to $PUBLIC_URI"

if [ -n "$JMX_PORT" ]
then
  echo "Enabling JMX connection on port: $JMX_PORT"
  JAVA_OPTS="${JAVA_OPTS:-} -Dcom.sun.management.jmxremote \
                            -Dcom.sun.management.jmxremote.port=$JMX_PORT \
                            -Dcom.sun.management.jmxremote.rmi.port=$JMX_PORT \
                            -Djava.rmi.server.hostname=127.0.0.1 \
                            -Dcom.sun.management.jmxremote.ssl=false \
                            -Dcom.sun.management.jmxremote.local.only=false \
                            -Dcom.sun.management.jmxremote.authenticate=false"
fi

if [ -n "$JVM_HEAP" ]
then
  echo "Setting heap to $JVM_HEAP"
  JAVA_OPTS="${JAVA_OPTS:-} -Xms$JVM_HEAP -Xmx$JVM_HEAP"
fi


if [ -n "$JVM_METASPACE" ]
then
  echo "Setting metaspace to $JVM_METASPACE"
  JAVA_OPTS="${JAVA_OPTS:-} -XX:MetaspaceSize=$JVM_METASPACE -XX:MaxMetaspaceSize=$JVM_METASPACE"
fi


if [ -n "$DEBUG_PORT" ]
then
  echo "Enabling debugging on port: $DEBUG_PORT"
  JAVA_OPTS="${JAVA_OPTS:-} -Xdebug -Xrunjdwp:transport=dt_socket,suspend=n,server=y,address=$DEBUG_PORT"
fi

### WaveFront Configuration
if [ -z "$WAVEFRONT_TAGS" ]
then
  WAVEFRONT_TAGS="product:lemans,app:lemans-gateway"
fi
JAVA_OPTS="${JAVA_OPTS:-} -Dlemans.wavefront.tags=$WAVEFRONT_TAGS"
echo "Setting WAVEFRONT_TAGS: $WAVEFRONT_TAGS"

if [ -n "$WAVEFRONT_PROXY" ]
then
  JAVA_OPTS="${JAVA_OPTS:-} -Dlemans.wavefront.proxy=$WAVEFRONT_PROXY"
  echo "Setting WAVEFRONT_PROXY: $WAVEFRONT_PROXY"
fi

ENABLE_KAFKA_CONFIG_OPTIONS=""
if [ "$ENABLE_KAFKA_CONFIG" = "True" ] ; then
  echo "Enabling kafka-config"
  ENABLE_KAFKA_CONFIG_OPTIONS="--kafkaConfigFile=/opt/le-mans/kafka/kafkaConfigFile"
fi

ENABLE_WHITELISTED_ROLES_OPTIONS=""
if [ "$ENABLE_WHITELISTED_ROLES" = "True" ] ; then
  echo "Enabling whitelisted service roles"
  ENABLE_WHITELISTED_ROLES_OPTIONS="-Dlemans.registration.allowedCspPermissions=$WHITELISTED_ROLES"
fi

if [ -n "$PROMETHEUS_METRICS_URI" ]
then
  JAVA_OPTS="${JAVA_OPTS:-} -Dlemans.gateway.prometheus.metrics.uri=$PROMETHEUS_METRICS_URI"
  echo "Setting PROMETHEUS_METRICS_URI: $PROMETHEUS_METRICS_URI"
fi

ENABLE_AVAILABILITY_ZONE=""
if [ -n "$AVAILABILITY_ZONE" ] ; then
  echo "Enabling availability zone"
  ENABLE_AVAILABILITY_ZONE="--availabilityZone=$AVAILABILITY_ZONE"
fi

ENABLE_SM_CONFIG_OPTIONS=""
if [ "$ENABLE_SM_CONFIG" = "True" ] ; then
  echo "Enabling sm-config"
  ENABLE_SM_CONFIG_OPTIONS="--isSMDeployment=true --enableSmJwtTokenAuth=true --smAuthConfigFile=/opt/le-mans/sm/smConfigFile"
fi

if [ -n "$METRICS_MANAGER_LOG_OPTION" ]
then
  JAVA_OPTS="${JAVA_OPTS:-} -Dlemans.MetricsManager.logOption=$METRICS_MANAGER_LOG_OPTION"
  echo "Setting METRICS_MANAGER_LOG_OPTION: $METRICS_MANAGER_LOG_OPTION"
fi

CACHE_CONFIG_FILE="${CACHE_CONFIG_FILE:+--cacheConfigFile=${CACHE_CONFIG_FILE}}"
[ -n "CACHE_CONFIG_FILE" ] && echo "Set CACHE_CONFIG_FILE to $CACHE_CONFIG_FILE"

echo $FIPS_MODE
SECURITY_CLASSPATH="" # This should be empty if FIPS_MODE is DISABLED
APP_ARGUMENTS_FOR_FIPS_MODE="" # Should be empty if FIPS_MODE is DISABLED
SECURITY_PARAMS="" # Should be empty if FIPS_MODE is DISABLED
# FIPS_MODE can be of 3 types: DISABLED, STRONG, CNSA.
if [ $FIPS_MODE == "STRONG" ] || [ $FIPS_MODE == "CNSA" ];
then
  #SECURITY PROVIDER CONFIGURATION
  SECURITY_PATH="/opt/vmware/security"
  SECURITY_PROVIDER_JAR="${SECURITY_PATH}/$(ls $SECURITY_PATH | grep 'bc-fips.*.jar')"
  SECURITY_PROVIDER_JAR="$SECURITY_PROVIDER_JAR:${SECURITY_PATH}/$(ls $SECURITY_PATH | grep 'bctls-fips.*.jar')"
  SECURITY_PROVIDER="org.bouncycastle.jcajce.provider.BouncyCastleFipsProvider"
  STORE_TYPE="BCFKS" # This needs to be configured in kafka.properties as well
  echo "-----SECURITY PROVIDER CONFIGURATION-----"
  echo $SECURITY_PATH
  echo $SECURITY_PROVIDER_JAR
  echo $SECURITY_PROVIDER
  echo $STORE_TYPE
  echo "-----------------------------------------"
  if [ $FIPS_MODE == "CNSA" ];
  then
    echo "Update JAVA_OPTS to include enablement of BouncyCastle security provider for FIPS compliance (CNSA variant)"
    JAVA_OPTS_FIPS=$(sed -e '/^\#/d' -e 's/-D/ -D/g' $SECURITY_PATH/java.properties.cnsa | tr -d '\n')
  else
    echo "Update JAVA_OPTS to include enablement of BouncyCastle security provider for FIPS compliance (STRONG variant)"
    JAVA_OPTS_FIPS=$(sed -e '/^\#/d' -e 's/-D/ -D/g' $SECURITY_PATH/java.properties.fips | tr -d '\n')
  fi
  JAVA_OPTS="${JAVA_OPTS:-} ${JAVA_OPTS_FIPS}"

  echo "Configuring BCFIPS keytool parameters to create keystore and truststore at runtime"
  SECURITY_PARAMS="-providerpath ${SECURITY_PROVIDER_JAR} -provider ${SECURITY_PROVIDER} -storetype ${STORE_TYPE}"

  echo "Configuring classpath for FIPS mode"
  SECURITY_CLASSPATH="${SECURITY_PROVIDER_JAR}:"

  echo "Adding application arguments specific to fips mode"
  APP_ARGUMENTS_FOR_FIPS_MODE="--fipsMode=$FIPS_MODE"
  echo "Creating cacert for BCFKS"
  keytool -importkeystore -srckeystore ${SECURITY_PATH}/cacerts -srcstoretype jks \
    -srcstorepass changeit -destkeystore ${SECURITY_PATH}/cacerts_bcfks -deststoretype ${STORE_TYPE} \
    -deststorepass changeit -destprovidername BCFIPS -providerpath ${SECURITY_PROVIDER_JAR} \
    -provider ${SECURITY_PROVIDER}
fi

if [ "$ENABLE_VDP_LEMANS_KAFKA_NEW" = "True" ] ; then
  for vdpLemansKafkaNew in `ls /opt/le-mans/vdp-ssl-certs-new/`; do
    VDP_SSL_CERT_PATH=/opt/le-mans/vdp-ssl-certs-new/$vdpLemansKafkaNew

    if [ -d  $VDP_SSL_CERT_PATH ]
    then
      SSL_PASSWORD_VAR=SSL_KEY_PASSWORD_$(echo $vdpLemansKafkaNew | awk -F- '{print $3}' | tr 'a-z' 'A-Z')
      VDP_SSL_MOUNT_PATH=/opt/le-mans/vdp-keystores-new/$vdpLemansKafkaNew
      eval VDP_SSL_KEY_PASSWORD='$'$SSL_PASSWORD_VAR
      VDP_KEYSTORE_LOCATION="/opt/le-mans/vdp-keystores-new/$vdpLemansKafkaNew/kafka.client.keystore.jks"
      VDP_TRUSTSTORE_LOCATION="/opt/le-mans/vdp-keystores-new/$vdpLemansKafkaNew/kafka.client.truststore.jks"

      echo "-----------------------"
      echo $VDP_KEYSTORE_LOCATION
      echo $VDP_TRUSTSTORE_LOCATION
      echo "-----------------------"

      # We use a k8s construct called emptyDir that survives container crashes.
      # Therefore we need to manually clean up contents of the emptyDir every time
      # this script runs to prevent errors of the keytool trying to import
      # same entry twice and can also pick up renewed certs.
      rm -rf $VDP_TRUSTSTORE_LOCATION
      rm -rf $VDP_KEYSTORE_LOCATION
      rm -rf $VDP_SSL_MOUNT_PATH/vdp-kafka.p12

      # The PKCS#12 or PFX format is a binary format for storing the server certificate,
      # any intermediate certificates, and the private key into a single encryptable file.
      # Below command creates a .p12 file that contains the pem files containing
      # certificate chains (root, intermediate, and cert) and the corresponding
      # key
      OPENSSL_CONF=./dummy-file openssl pkcs12 -export -in $VDP_SSL_CERT_PATH/chain -inkey $VDP_SSL_CERT_PATH/privateKey \
        -passin pass:$VDP_SSL_KEY_PASSWORD -out $VDP_SSL_MOUNT_PATH/vdp-kafka.p12 \
        -passout pass:$VDP_SSL_KEY_PASSWORD -certpbe AES-256-CBC -keypbe AES-256-CBC -macalg SHA256 -aes256

      # Below command creates a keystore at runtime.
      keytool -importkeystore -deststorepass $VDP_SSL_KEY_PASSWORD -destkeypass \
        $VDP_SSL_KEY_PASSWORD -destkeystore $VDP_KEYSTORE_LOCATION -srckeystore $VDP_SSL_MOUNT_PATH/vdp-kafka.p12 \
        -srcstoretype PKCS12 -srcstorepass $VDP_SSL_KEY_PASSWORD

      # Below command creates a truststore at runtime
      COUNTER=0
      for filename in `ls $VDP_SSL_CERT_PATH/root*`; do
        echo "Importing root cert $filename"
        keytool -noprompt -keystore $VDP_TRUSTSTORE_LOCATION -alias vdp-root-$COUNTER \
          -import -file $filename -storepass $VDP_SSL_KEY_PASSWORD -trustcacerts
        COUNTER=$((COUNTER+1))
      done
    fi
  done
fi

if [ "$ENABLE_VDP_LEMANS_KAFKA" = "True" ] ; then
  for vdpLemansKafka in `ls /opt/le-mans/vdp-ssl-certs/`; do
    VDP_SSL_CERT_PATH=/opt/le-mans/vdp-ssl-certs/$vdpLemansKafka

    if [ -d  $VDP_SSL_CERT_PATH ]
    then
      SSL_PASSWORD_VAR=SSL_KEY_PASSWORD_$(echo $vdpLemansKafka | awk -F- '{print $3}' | tr 'a-z' 'A-Z')
      VDP_SSL_MOUNT_PATH=/opt/le-mans/vdp-keystores/$vdpLemansKafka
      eval VDP_SSL_KEY_PASSWORD='$'$SSL_PASSWORD_VAR
      VDP_KEYSTORE_LOCATION="/opt/le-mans/vdp-keystores/$vdpLemansKafka/kafka.client.keystore.jks"
      VDP_TRUSTSTORE_LOCATION="/opt/le-mans/vdp-keystores/$vdpLemansKafka/kafka.client.truststore.jks"

      echo "-----------------------"
      echo $VDP_KEYSTORE_LOCATION
      echo $VDP_TRUSTSTORE_LOCATION
      echo "-----------------------"

      # We use a k8s construct called emptyDir that survives container crashes.
      # Therefore we need to manually clean up contents of the emptyDir every time
      # this script runs to prevent errors of the keytool trying to import
      # same entry twice and can also pick up renewed certs.
      rm -rf $VDP_TRUSTSTORE_LOCATION
      rm -rf $VDP_KEYSTORE_LOCATION
      rm -rf $VDP_SSL_MOUNT_PATH/vdp-kafka.p12

      # The PKCS#12 or PFX format is a binary format for storing the server certificate,
      # any intermediate certificates, and the private key into a single encryptable file.
      # Below command creates a .p12 file that contains the pem files containing
      # certificate chains (root, intermediate, and cert) and the corresponding
      # key
      OPENSSL_CONF=./dummy-file openssl pkcs12 -export -in $VDP_SSL_CERT_PATH/chain -inkey $VDP_SSL_CERT_PATH/privateKey \
        -passin pass:$VDP_SSL_KEY_PASSWORD -out $VDP_SSL_MOUNT_PATH/vdp-kafka.p12 \
        -passout pass:$VDP_SSL_KEY_PASSWORD -certpbe AES-256-CBC -keypbe AES-256-CBC -macalg SHA256 -aes256

      # Below command creates a keystore at runtime.
      keytool -importkeystore -deststorepass $VDP_SSL_KEY_PASSWORD -destkeypass \
        $VDP_SSL_KEY_PASSWORD -destkeystore $VDP_KEYSTORE_LOCATION -srckeystore $VDP_SSL_MOUNT_PATH/vdp-kafka.p12 \
        -srcstoretype PKCS12 -srcstorepass $VDP_SSL_KEY_PASSWORD

      # Below command creates a truststore at runtime
      COUNTER=0
      for filename in `ls $VDP_SSL_CERT_PATH/root*`; do
        echo "Importing root cert $filename"
        keytool -noprompt -keystore $VDP_TRUSTSTORE_LOCATION -alias vdp-root-$COUNTER \
          -import -file $filename -storepass $VDP_SSL_KEY_PASSWORD -trustcacerts
        COUNTER=$((COUNTER+1))
      done
    fi
  done
fi


SSL_CERT_PATH=/opt/le-mans/ssl-certs

if [ -d  $SSL_CERT_PATH ]
then
  SSL_MOUNT_PATH=/opt/le-mans/kafka/ssl
  SSL_KEY_PASSWORD="VMware1234"
  KEYSTORE_LOCATION="/opt/le-mans/kafka/ssl/lemans.diploma.keystore.jks"
  TRUSTSTORE_LOCATION="/opt/le-mans/kafka/ssl/lemans.diploma.truststore.jks"

  echo "-----------------------"
  echo $KEYSTORE_LOCATION
  echo $TRUSTSTORE_LOCATION
  echo "-----------------------"

  # We use a k8s construct called emptyDir that survives container crashes.
  # Therefore we need to manually clean up contents of the emptyDir every time
  # this script runs to prevent errors of the keytool trying to import
  # same entry twice and can also pick up renewed certs.
  rm -rf $TRUSTSTORE_LOCATION
  rm -rf $KEYSTORE_LOCATION
  rm -rf $SSL_MOUNT_PATH/localhost.p12
  rm -rf $SSL_MOUNT_PATH/root-bundle.pem

  cat $SSL_CERT_PATH/root*.pem > $SSL_MOUNT_PATH/root-bundle.pem
  # The PKCS#12 or PFX format is a binary format for storing the server certificate,
  # any intermediate certificates, and the private key into a single encryptable file.
  # Below command creates a .p12 file that contains the pem files containing
  # certificate chains (root, intermediate, and cert) and the corresponding
  # key
  OPENSSL_CONF=./dummy-file openssl pkcs12 -export -in $SSL_CERT_PATH/chain.pem -inkey $SSL_CERT_PATH/key.pem \
    -out $SSL_MOUNT_PATH/localhost.p12 -name localhost -CAfile $SSL_MOUNT_PATH/root-bundle.pem \
    -passout pass:$SSL_KEY_PASSWORD -certpbe AES-256-CBC -keypbe AES-256-CBC -macalg SHA256 -aes256

  # Below command creates a keystore at runtime.
  keytool $SECURITY_PARAMS -importkeystore -deststorepass $SSL_KEY_PASSWORD -destkeypass \
    $SSL_KEY_PASSWORD -destkeystore $KEYSTORE_LOCATION -srckeystore $SSL_MOUNT_PATH/localhost.p12 \
    -srcstoretype PKCS12 -srcstorepass $SSL_KEY_PASSWORD -alias localhost

  # Below command creates a truststore at runtime
  COUNTER=0
  for filename in `ls $SSL_CERT_PATH/root*.pem`; do
    echo "Importing root cert $filename"
    keytool $SECURITY_PARAMS -noprompt -keystore $TRUSTSTORE_LOCATION -alias diploma-$COUNTER \
      -import -file $filename -storepass $SSL_KEY_PASSWORD -trustcacerts
    COUNTER=$((COUNTER+1))
  done
fi

LINT_SSL_CERT_PATH=/opt/le-mans/ssl-certs/lint

if [ -d  $LINT_SSL_CERT_PATH ]
then
  SSL_MOUNT_PATH=/opt/le-mans/kafka/ssl/lint
  SSL_KEY_PASSWORD="VMware1234"
  KEYSTORE_LOCATION="/opt/le-mans/kafka/ssl/lint/lemans.diploma.keystore.jks"
  TRUSTSTORE_LOCATION="/opt/le-mans/kafka/ssl/lint/lemans.diploma.truststore.jks"

  echo "-----------------------"
  echo $KEYSTORE_LOCATION
  echo $TRUSTSTORE_LOCATION
  echo "-----------------------"

  # We use a k8s construct called emptyDir that survives container crashes.
  # Therefore we need to manually clean up contents of the emptyDir every time
  # this script runs to prevent errors of the keytool trying to import
  # same entry twice and can also pick up renewed certs.
  rm -rf $TRUSTSTORE_LOCATION
  rm -rf $KEYSTORE_LOCATION
  rm -rf $SSL_MOUNT_PATH/localhost.p12
  rm -rf $SSL_MOUNT_PATH/root-bundle.pem

  cat $LINT_SSL_CERT_PATH/root*.pem > $SSL_MOUNT_PATH/root-bundle.pem
  # The PKCS#12 or PFX format is a binary format for storing the server certificate,
  # any intermediate certificates, and the private key into a single encryptable file.
  # Below command creates a .p12 file that contains the pem files containing
  # certificate chains (root, intermediate, and cert) and the corresponding
  # key
  OPENSSL_CONF=./dummy-file openssl pkcs12 -export -in $LINT_SSL_CERT_PATH/chain.pem -inkey $LINT_SSL_CERT_PATH/key.pem \
    -out $SSL_MOUNT_PATH/localhost.p12 -name localhost -CAfile $SSL_MOUNT_PATH/root-bundle.pem \
    -passout pass:$SSL_KEY_PASSWORD -certpbe AES-256-CBC -keypbe AES-256-CBC -macalg SHA256 -aes256

  # Below command creates a keystore at runtime.
  keytool $SECURITY_PARAMS -importkeystore -deststorepass $SSL_KEY_PASSWORD -destkeypass \
    $SSL_KEY_PASSWORD -destkeystore $KEYSTORE_LOCATION -srckeystore $SSL_MOUNT_PATH/localhost.p12 \
    -srcstoretype PKCS12 -srcstorepass $SSL_KEY_PASSWORD -alias localhost

  # Below command creates a truststore at runtime
  COUNTER=0
  for filename in `ls $LINT_SSL_CERT_PATH/root*.pem`; do
    echo "Importing root cert $filename"
    keytool $SECURITY_PARAMS -noprompt -keystore $TRUSTSTORE_LOCATION -alias diploma-$COUNTER \
      -import -file $filename -storepass $SSL_KEY_PASSWORD -trustcacerts
    COUNTER=$((COUNTER+1))
  done
fi

if [ "$ENABLE_ATLAS_LEMANS_KAFKA" = "True" ] ; then
  for atlasLemansKafka in `ls /opt/le-mans/msk-ssl-certs/`; do
    MSK_SSL_CERT_PATH=/opt/le-mans/msk-ssl-certs/$atlasLemansKafka

    if [ -d  $MSK_SSL_CERT_PATH ]
    then
      SSL_PASSWORD_VAR=SSL_KEY_PASSWORD_$(echo $atlasLemansKafka | awk -F- '{print $3}' | tr 'a-z' 'A-Z')
      MSK_SSL_MOUNT_PATH=/opt/le-mans/msk-keystores/$atlasLemansKafka
      eval MSK_SSL_KEY_PASSWORD='$'$SSL_PASSWORD_VAR
      MSK_KEYSTORE_LOCATION="/opt/le-mans/msk-keystores/$atlasLemansKafka/kafka.client.keystore.jks"
      MSK_TRUSTSTORE_LOCATION="/opt/le-mans/msk-keystores/$atlasLemansKafka/kafka.client.truststore.jks"

      echo "-----------------------"
      echo $MSK_KEYSTORE_LOCATION
      echo $MSK_TRUSTSTORE_LOCATION
      echo "-----------------------"

      # We use a k8s construct called emptyDir that survives container crashes.
      # Therefore we need to manually clean up contents of the emptyDir every time
      # this script runs to prevent errors of the keytool trying to import
      # same entry twice and can also pick up renewed certs.
      rm -rf $MSK_TRUSTSTORE_LOCATION
      rm -rf $MSK_KEYSTORE_LOCATION
      rm -rf $MSK_SSL_MOUNT_PATH/msk-kafka.p12

      # The PKCS#12 or PFX format is a binary format for storing the server certificate,
      # any intermediate certificates, and the private key into a single encryptable file.
      # Below command creates a .p12 file that contains the pem files containing
      # certificate chains (root, intermediate, and cert) and the corresponding
      # key
      OPENSSL_CONF=./dummy-file openssl pkcs12 -export -in $MSK_SSL_CERT_PATH/chain -inkey $MSK_SSL_CERT_PATH/privateKey \
        -passin pass:$MSK_SSL_KEY_PASSWORD -out $MSK_SSL_MOUNT_PATH/msk-kafka.p12 \
        -passout pass:$MSK_SSL_KEY_PASSWORD -certpbe AES-256-CBC -keypbe AES-256-CBC -macalg SHA256 -aes256

      # Below command creates a keystore at runtime.
      keytool $SECURITY_PARAMS -importkeystore -deststorepass $MSK_SSL_KEY_PASSWORD -destkeypass \
        $MSK_SSL_KEY_PASSWORD -destkeystore $MSK_KEYSTORE_LOCATION -srckeystore $MSK_SSL_MOUNT_PATH/msk-kafka.p12 \
        -srcstoretype PKCS12 -srcstorepass $MSK_SSL_KEY_PASSWORD -deststoretype JKS

      # Below command creates a truststore at runtime
      COUNTER=0
      for filename in `ls $MSK_SSL_CERT_PATH/root*`; do
        echo "Importing root cert $filename"
        keytool $SECURITY_PARAMS -noprompt -keystore $MSK_TRUSTSTORE_LOCATION -alias aws-root-$COUNTER \
          -import -file $filename -storepass $MSK_SSL_KEY_PASSWORD -trustcacerts
        COUNTER=$((COUNTER+1))
      done
    fi
  done
fi

echo "$(date): starting jvm with JAVA_OPTS:${JAVA_OPTS}"

status=0
set +e
java ${JAVA_OPTS} \
                  $ENABLE_WHITELISTED_ROLES_OPTIONS \
                  -Dlogback.configurationFile=$LEMS_HOME/logback.xml \
                  -Dlog4j2.formatMsgNoLookups=true \
                   -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=/var/log/ \
                  -cp $SECURITY_CLASSPATH$LEMS_HOME/lib/le-mans-gateway.jar \
                  -Dloader.main=com.vmware.lemans.gateway.GatewayHost \
                  org.springframework.boot.loader.PropertiesLauncher \
                  --port=$BINDING_PORT --bindAddress=$BINDING_ADDRESS --publicUri=$PUBLIC_URI \
                  --cspClientId=$CSP_CLIENT_ID \
                  --cspClientSecret=$CSP_CLIENT_SECRET \
                  --resourcesHostUri=$RESOURCES_HOST_URI $ENABLE_KAFKA_CONFIG_OPTIONS $ENABLE_AVAILABILITY_ZONE $ENABLE_SM_CONFIG_OPTIONS \
                  $APP_ARGUMENTS_FOR_FIPS_MODE $CACHE_CONFIG_FILE "$@"

status=$?
set -e

echo "$(date): jvm exited with status code ${status}"
exit ${status}

